﻿using Microsoft.UI.Xaml.Controls;
using System.Collections.ObjectModel;
using Windows.Foundation;
using Windows.Graphics.Display;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace TestProject
{
    /// <summary>
    /// 메인 페이지
    /// </summary>
    public sealed partial class MainPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// 
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region Field

        /// <summary>
        /// 커스텀 항목 컬렉션
        /// </summary>
        private ObservableCollection<CustomItem> customItemCollection;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainPage()
        {
            InitializeComponent();

            #region 윈도우 크기를 설정한다.

            double width  = 800d;
            double height = 600d;

            double dpi = (double)DisplayInformation.GetForCurrentView().LogicalDpi;

            ApplicationView.PreferredLaunchWindowingMode = ApplicationViewWindowingMode.PreferredLaunchViewSize;

            Size windowSize = new Size(width * 96d / dpi, height * 96d / dpi);

            ApplicationView.PreferredLaunchViewSize = windowSize;

            Window.Current.Activate();

            ApplicationView.GetForCurrentView().TryResizeView(windowSize);

            #endregion
            #region 윈도우 제목을 설정한다.

            ApplicationView.GetForCurrentView().Title = "TabView 엘리먼트 : TabItemsSource 속성을 사용해 데이터 바인딩하기";

            #endregion

            this.customItemCollection = new ObservableCollection<CustomItem>();

            for(int index = 0; index < 3; index++)
            {
                CustomItem item = GetCustomItem(index);

                this.customItemCollection.Add(item);
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 탭뷰 탭 추가 버튼 클릭시 처리하기 - tabView_AddTabButtonClick(tabView, e)

        /// <summary>
        /// 탭뷰 탭 추가 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="tabView">탭 뷰</param>
        /// <param name="e">이벤트 인자</param>
        private void tabView_AddTabButtonClick(TabView tabView, object e)
        {
            CustomItem item = GetCustomItem(this.customItemCollection.Count);

            this.customItemCollection.Add(item);
        }

        #endregion
        #region 탭뷰 탭 닫기 요청시 처리하기 - tabView_TabCloseRequested(tabView, e)

        /// <summary>
        /// 탭뷰 탭 닫기 요청시 처리하기
        /// </summary>
        /// <param name="tabView">탭뷰</param>
        /// <param name="e">이벤트 인자</param>
        private void tabView_TabCloseRequested(TabView tabView, TabViewTabCloseRequestedEventArgs e)
        {
            CustomItem item = e.Item as CustomItem;

            this.customItemCollection.Remove(item);
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 커스텀 항목 구하기 - GetCustomItem(index)

        /// <summary>
        /// 커스텀 항목 구하기
        /// </summary>
        /// <param name="index">인덱스</param>
        /// <returns>커스텀 항목</returns>
        private CustomItem GetCustomItem(int index)
        {
            CustomItem item = new CustomItem
            {
                DataHeader    = $"문서 {index}",
                DataIconSource = new Microsoft.UI.Xaml.Controls.SymbolIconSource() { Symbol = Symbol.Placeholder }
            };

            Frame frame = new Frame();

            switch(index % 3)
            {
                case 0 : frame.Navigate(typeof(SamplePage1)); break;
                case 1 : frame.Navigate(typeof(SamplePage2)); break;
                case 2 : frame.Navigate(typeof(SamplePage3)); break;
            }

            item.DataContent = frame;

            return item;
        }

        #endregion
    }
}